@@ -46,21 +46,16 @@ class BaseResponse(object):
         self._sijax = sijax_instance
         self._request_args = request_args
     
-    @property
-    def request_args(self):
-        """Returns the arguments array to pass to callbacks.
+    def _get_request_args(self):
+        """Returns the arguments list to pass to callbacks.
 
-        This class doesn't manipulate them, so it returns the original arguments,
+        This class doesn't manipulate them, so it returns the original call arguments,
         but other classes can override them however they need.
         """
         return self._request_args
         
-    def add_command(self, cmd_type, params = None):
-        """Adds a raw command to the buffer to send to the client.
-
-        You generally don't need to use this at all,
-        unless you really know what you're doing.
-        """
+    def _add_command(self, cmd_type, params = None):
+        """Adds a raw command to the buffer to send to the client."""
         if params is None:
             params = {}
         params['type'] = cmd_type
@@ -69,22 +64,25 @@ class BaseResponse(object):
         return self
     
     def clear_commands(self):
-        """Clears the commands buffer."""
+        """Clears the commands buffer.
+
+        All the commands added by other methods will be removed.
+        """
         self._commands = []
         return self
 
     def alert(self, message):
         """Sends a window.alert command to the browser."""
         params = {self.__class__.COMMAND_ALERT: message}
-        return self.add_command(self.__class__.COMMAND_ALERT, params)
+        return self._add_command(self.__class__.COMMAND_ALERT, params)
     
     def _html(self, selector, html, set_type):
         params = {"selector": selector, "html": html, "setType": set_type}
-        return self.add_command(self.__class__.COMMAND_HTML, params)
+        return self._add_command(self.__class__.COMMAND_HTML, params)
    
     def html(self, selector, html):
         """
-        Adds the given html to the element specified by the selector,
+        Adds the given html to the element(s) specified by the jQuery selector,
         replacing any html content inside it.
 
         Scripts inside the html block are also executed.
@@ -95,7 +93,9 @@ class BaseResponse(object):
         return self._html(selector, html, "replace")
 
     def html_append(self, selector, html):
-        """Appends the given html to the element specified by the selector.
+        """Appends the given html to the element(s) specified by the jQuery selector.
+
+        Same as jQuery's: $(selector).html(value);
 
         Scripts inside the html block are also executed.
 
@@ -105,7 +105,7 @@ class BaseResponse(object):
         return self._html(selector, html, "append")
    
     def html_prepend(self, selector, html):
-        """Prepends the given html to the element specified by the selector.
+        """Prepends the given html to the element(s) specified by the jQuery selector.
 
         Scripts inside the html block are also executed.
 
@@ -122,13 +122,14 @@ class BaseResponse(object):
         unless you explicitly do it.
         """
         params = {self.__class__.COMMAND_SCRIPT: js}
-        return self.add_command(self.__class__.COMMAND_SCRIPT, params)
+        return self._add_command(self.__class__.COMMAND_SCRIPT, params)
 
     def css(self, selector, property_name, value):
-        """Assigns a new style property value to all elements matching the selector.
+        """Assigns a new style property value to all elements matching the jQuery selector.
 
         Finds an element by the specified selector and changes
         the specified css (style) property to the given value.
+
         Same as jQuery's $(selector).css('property', 'value');
 
         Note that this can only change a single property at once.
@@ -140,17 +141,17 @@ class BaseResponse(object):
         :param value: the new value to assign to the property
         """
         params = {"selector": selector, "key": property_name, "value": value}
-        return self.add_command(self.__class__.COMMAND_CSS, params)
+        return self._add_command(self.__class__.COMMAND_CSS, params)
 
     def _attr(self, selector, property_name, value, set_type):
         params = {
             "selector": selector, "key": property_name,
             "value": value, "setType": set_type
         }
-        return self.add_command(self.__class__.COMMAND_ATTR, params)
+        return self._add_command(self.__class__.COMMAND_ATTR, params)
 
     def attr(self, selector, property_name, value):
-        """Assigns an attribute value to all elements matching the selector.
+        """Assigns an attribute value to all elements matching the jQuery selector.
 
         Finds an element by the specified selector and changes
         the specified property to the given value.
@@ -163,17 +164,20 @@ class BaseResponse(object):
         return self._attr(selector, property_name, value, "replace")
     
     def attr_append(self, selector, property_name, value):
-        """Same as attr(), but appends instead of assigning a new value."""
+        """Same as :meth:`attr`, but appends instead of assigning a new value."""
         return self._attr(selector, property_name, value, "append")
 
     def attr_prepend(self, selector, property_name, value):
-        """Same as attr(), but prepends instead of assigning a new value."""
+        """Same as :meth:`attr`, but prepends instead of assigning a new value."""
         return self._attr(selector, property_name, value, "prepend")
     
     def remove(self, selector):
-        """Removes all elements from the DOM that match the selector."""
+        """Removes all elements from the DOM that match the selector.
+
+        Same as jQuery's: $(selector).remove();
+        """
         params = {self.__class__.COMMAND_REMOVE: selector}
-        return self.add_command(self.__class__.COMMAND_REMOVE, params)
+        return self._add_command(self.__class__.COMMAND_REMOVE, params)
 
     
     def redirect(self, uri):
@@ -193,9 +197,9 @@ class BaseResponse(object):
             raise SijaxError("call() expects a list, a tuple or None for the args list")
 
         params = {self.__class__.COMMAND_CALL: js_func_name, "params": func_params}
-        return self.add_command(self.__class__.COMMAND_CALL, params)
+        return self._add_command(self.__class__.COMMAND_CALL, params)
     
-    def get_json(self):
+    def _get_json(self):
         """Returns a JSON representation of the commands buffer list.
 
         The client side code will loop over the list and execute all the
@@ -240,5 +244,5 @@ class BaseResponse(object):
         """
         for callback, args in call_chain:
             self._process_callback(callback, args)
-        return self.get_json()
+        return self._get_json()
 
